@@ -21,11 +21,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define PLAYER_H
 
 extern object player;
+extern bool player_chargerFired;
 
 extern void initPlayer();
 void player_setTarget(int index);
+char player_checkShockDamage(float x, float y);
 extern void exitPlayer();
-extern void doPlayer();
 extern void flushInput();
 extern void getPlayerInput();
 extern void leaveSector();
